==> igniteui-angular-charts-16.1.2-beta.0.tgz: package/esm2015/lib/StackedSeriesVisualData.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { SeriesVisualData } from "./SeriesVisualData";
import { SeriesVisualDataList } from "./SeriesVisualDataList";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
export let StackedSeriesVisualData = /*@__PURE__*/ (() => {
    class StackedSeriesVisualData extends SeriesVisualData {
        constructor() {
            super();
            this._fragmentSeries = null;
            this.fragmentSeries = new SeriesVisualDataList();
        }
        get fragmentSeries() {
            return this._fragmentSeries;
        }
        set fragmentSeries(a) {
            this._fragmentSeries = a;
        }
        m() {
            super.m();
            for (let a = 0; a < this.fragmentSeries.count; a++) {
                this.fragmentSeries._inner[a].m();
            }
        }
        n(a) {
            super.n(a);
            if (this.fragmentSeries != null && this.fragmentSeries.count > 0) {
                a.u(",");
                a.u("fragmentSeries: [");
                for (let b = 0; b < this.fragmentSeries.count; b++) {
                    if (b > 0) {
                        a.u(",");
                    }
                    a.l(this.fragmentSeries._inner[b].serialize());
                }
                a.u("]");
            }
        }
    }
    StackedSeriesVisualData.$t = markType(StackedSeriesVisualData, 'StackedSeriesVisualData', SeriesVisualData.$);
    return StackedSeriesVisualData;
})();

==> igniteui-angular-charts-17.2.0-beta.0.tgz: package/esm2015/lib/StackedSeriesVisualData.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { SeriesVisualData } from "./SeriesVisualData";
import { SeriesVisualDataList } from "./SeriesVisualDataList";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
export let StackedSeriesVisualData = /*@__PURE__*/ (() => {
    class StackedSeriesVisualData extends SeriesVisualData {
        constructor() {
            super();
            this._fragmentSeries = null;
            this.fragmentSeries = new SeriesVisualDataList();
        }
        get fragmentSeries() {
            return this._fragmentSeries;
        }
        set fragmentSeries(a) {
            this._fragmentSeries = a;
        }
        n() {
            super.n();
            for (let a = 0; a < this.fragmentSeries.count; a++) {
                this.fragmentSeries._inner[a].n();
            }
        }
        o(a) {
            super.o(a);
            if (this.fragmentSeries != null && this.fragmentSeries.count > 0) {
                a.u(",");
                a.u("fragmentSeries: [");
                for (let b = 0; b < this.fragmentSeries.count; b++) {
                    if (b > 0) {
                        a.u(",");
                    }
                    a.l(this.fragmentSeries._inner[b].serialize());
                }
                a.u("]");
            }
        }
    }
    StackedSeriesVisualData.$t = markType(StackedSeriesVisualData, 'StackedSeriesVisualData', SeriesVisualData.$);
    return StackedSeriesVisualData;
})();
